# django-pgbulk

## Compatibility

`django-pgbulk` is compatible with Python 3.8 - 3.12, Django 3.2 - 4.2, Psycopg 2 - 3, and Postgres 12 - 16.

## Documentation

[View the django-pgbulk docs here](https://django-pgbulk.readthedocs.io/)

## Installation

Install `django-pgbulk` with:

    pip3 install django-pgbulk

After this, add `pgbulk` to the `INSTALLED_APPS` setting of your Django project.

## Contributing Guide

For information on setting up django-pgbulk for development and contributing changes, view [CONTRIBUTING.md](CONTRIBUTING.md).
